{-
   Here we go.
-}

-- | This is the module's Haddock.
module Main (main) where

main = return ()
